@@ -1,18 +1,23 @@
 from pathlib import Path
 from typing import Any, Dict, get_type_hints
 
-from ._settings_store import UserSettingsStore, current_user_settings_file, settings_dir
+from ._settings_store import (
+    UserSettingsStore,
+    current_user_settings_file,
+    user_settings_file_email,
+    user_settings_file_handle,
+)
 from ._settings_user import UserSettings
 
 
 def save_user_settings(settings: UserSettings):
     assert settings.email is not None
     type_hints = get_type_hints(UserSettingsStore)
-    save_settings(settings, current_user_settings_file, type_hints)
-    save_settings(settings, settings_dir / f"user-{settings.email}.env", type_hints)
+    save_settings(settings, current_user_settings_file(), type_hints)
+    save_settings(settings, user_settings_file_email(settings.email), type_hints)
     if settings.handle is not None:
         save_settings(
-            settings, settings_dir / f"user-{settings.handle}.env", type_hints
+            settings, user_settings_file_handle(settings.handle), type_hints
         )  # noqa
 
 
